@@ -23,9 +23,9 @@
 
 #include <QAbstractItemModel>
 #include <QJSValue>
-#include <QSortFilterProxyModel>
-#include <QVector>
+#include <QList>
 #include <QQmlParserStatus>
+#include <QSortFilterProxyModel>
 
 /**
  * @class SortFilterModel
@@ -42,7 +42,6 @@ class KSortFilterProxyModel : public QSortFilterProxyModel, public QQmlParserSta
      */
     Q_PROPERTY(QAbstractItemModel *sourceModel READ sourceModel WRITE setModel NOTIFY sourceModelChanged)
 
-
     /**
      * The string for the filter, only rows with their filterRole matching filterString will be displayed
      */
@@ -75,13 +74,15 @@ class KSortFilterProxyModel : public QSortFilterProxyModel, public QQmlParserSta
 
     /**
      * The role of the sourceModel on which the filter will be applied.
+     * This can either be the numerical role value or the role name as a string.
      */
-    Q_PROPERTY(QString filterRole READ filterRole WRITE setFilterRole NOTIFY filterRoleChanged)
+    Q_PROPERTY(QString filterRoleName READ filterRoleName WRITE setFilterRoleName NOTIFY filterRoleNameChanged)
 
     /**
      * The role of the sourceModel that will be used for sorting. if empty the order will be left unaltered
+     * This can either be the numerical role value or the role name as a string.
      */
-    Q_PROPERTY(QString sortRole READ sortRole WRITE setSortRole NOTIFY sortRoleChanged)
+    Q_PROPERTY(QString sortRoleName READ sortRoleName WRITE setSortRoleName NOTIFY sortRoleNameChanged)
 
     /**
      * One of Qt.AscendingOrder or Qt.DescendingOrder
@@ -89,7 +90,7 @@ class KSortFilterProxyModel : public QSortFilterProxyModel, public QQmlParserSta
     Q_PROPERTY(Qt::SortOrder sortOrder READ sortOrder WRITE setSortOrder NOTIFY sortOrderChanged)
 
     /**
-     * Specify which column shoud be used for sorting
+     * Specify which column should be used for sorting
      * The default value is -1.
      * If \a sortRole is set, the default value is 0.
      */
@@ -102,7 +103,7 @@ class KSortFilterProxyModel : public QSortFilterProxyModel, public QQmlParserSta
 
 public:
     explicit KSortFilterProxyModel(QObject *parent = nullptr);
-    ~KSortFilterProxyModel();
+    ~KSortFilterProxyModel() override;
 
     void setModel(QAbstractItemModel *source);
 
@@ -115,11 +116,11 @@ public:
     void setFilterColumnCallback(const QJSValue &callback);
     QJSValue filterColumnCallback() const;
 
-    void setFilterRole(const QString &role);
-    QString filterRole() const;
+    void setFilterRoleName(const QString &roleName);
+    QString filterRoleName() const;
 
-    void setSortRole(const QString &role);
-    QString sortRole() const;
+    void setSortRoleName(const QString &roleName);
+    QString sortRoleName() const;
 
     void setSortOrder(const Qt::SortOrder order);
     void setSortColumn(int column);
@@ -140,8 +141,8 @@ public Q_SLOTS:
 
 Q_SIGNALS:
     void filterStringChanged();
-    void filterRoleChanged();
-    void sortRoleChanged();
+    void filterRoleNameChanged();
+    void sortRoleNameChanged();
     void sortOrderChanged();
     void sortColumnChanged();
     void sourceModelChanged(QObject *);
@@ -159,9 +160,9 @@ protected Q_SLOTS:
 
 private:
     bool m_componentCompleted = false;
-    QString m_filterRole;
+    QString m_filterRoleName;
     QString m_filterString;
-    QString m_sortRole;
+    QString m_sortRoleName;
     QJSValue m_filterRowCallback;
     QJSValue m_filterColumnCallback;
     QHash<QString, int> m_roleIds;
